@@ -29,8 +29,6 @@ from typing import (
 )
 
 import aiohttp
-from cryptography.hazmat.backends import default_backend
-from cryptography.x509 import load_pem_x509_certificate
 
 from google.auth.credentials import Credentials
 from google.cloud.sql.connector.exceptions import (
@@ -63,7 +61,7 @@ class IPTypes(Enum):
     PSC: str = "PSC"
 
 
-class InstanceMetadata:
+class ConnectionInfo:
     ip_addrs: Dict[str, Any]
     context: ssl.SSLContext
     database_version: str
@@ -205,7 +203,7 @@ class Instance:
 
     _refresh_rate_limiter: AsyncRateLimiter
     _refresh_in_progress: asyncio.locks.Event
-    _current: asyncio.Task  # task wraps coroutine that returns InstanceMetadata
+    _current: asyncio.Task  # task wraps coroutine that returns ConnectionInfo
     _next: asyncio.Task  # task wraps coroutine that returns another task
 
     def __init__(
@@ -255,7 +253,7 @@ class Instance:
         self._current = self._schedule_refresh(0)
         self._next = self._current
 
-    def force_refresh(self) -> None:
+    async def force_refresh(self) -> None:
         """
         Forces a new refresh attempt immediately to be used for future connection attempts.
         """
@@ -263,14 +261,15 @@ class Instance:
         if not self._refresh_in_progress.is_set():
             self._next.cancel()
             self._next = self._schedule_refresh(0)
-        # block all sequential connection attempts on the next refresh result
-        self._current = self._next
+        # block all sequential connection attempts on the next refresh result if current is invalid
+        if not await _is_valid(self._current):
+            self._current = self._next
 
-    async def _perform_refresh(self) -> InstanceMetadata:
+    async def _perform_refresh(self) -> ConnectionInfo:
         """Retrieves instance metadata and ephemeral certificate from the
         Cloud SQL Instance.
 
-        :rtype: InstanceMetadata
+        :rtype: ConnectionInfo
         :returns: A dataclass containing a string representing the ephemeral certificate, a dict
             containing the instances IP adresses, a string representing a PEM-encoded private key
             and a string representing a PEM-encoded certificate authority.
@@ -322,18 +321,7 @@ class Instance:
                 ephemeral_task.cancel()
                 raise
 
-            ephemeral_cert = await ephemeral_task
-
-            x509 = load_pem_x509_certificate(
-                ephemeral_cert.encode("UTF-8"), default_backend()
-            )
-            expiration = x509.not_valid_after
-
-            if self._enable_iam_auth:
-                if self._credentials is not None:
-                    token_expiration: datetime.datetime = self._credentials.expiry
-                if expiration > token_expiration:
-                    expiration = token_expiration
+            ephemeral_cert, expiration = await ephemeral_task
 
         except aiohttp.ClientResponseError as e:
             logger.debug(
@@ -352,7 +340,7 @@ class Instance:
         finally:
             self._refresh_in_progress.clear()
 
-        return InstanceMetadata(
+        return ConnectionInfo(
             ephemeral_cert,
             metadata["database_version"],
             metadata["ip_addresses"],
@@ -364,7 +352,7 @@ class Instance:
 
     def _schedule_refresh(self, delay: int) -> asyncio.Task:
         """
-        Schedule task to sleep and then perform refresh to get InstanceMetadata.
+        Schedule task to sleep and then perform refresh to get ConnectionInfo.
 
         :type delay: int
         :param delay
@@ -374,7 +362,7 @@ class Instance:
         :returns: A Task representing the scheduled _perform_refresh.
         """
 
-        async def _refresh_task(self: Instance, delay: int) -> InstanceMetadata:
+        async def _refresh_task(self: Instance, delay: int) -> ConnectionInfo:
             """
             A coroutine that sleeps for the specified amount of time before
             running _perform_refresh.
@@ -421,7 +409,7 @@ class Instance:
     async def connect_info(
         self,
         ip_type: IPTypes,
-    ) -> Tuple[InstanceMetadata, str]:
+    ) -> Tuple[ConnectionInfo, str]:
         """Retrieve instance metadata and ip address required
         for making connection to Cloud SQL instance.
 
@@ -429,7 +417,7 @@ class Instance:
         :param ip_type: Enum specifying whether to look for public
             or private IP address.
 
-        :rtype instance_data: InstanceMetadata
+        :rtype instance_data: ConnectionInfo
         :returns: Instance metadata for Cloud SQL instance.
 
         :rtype ip_address: str
@@ -440,7 +428,7 @@ class Instance:
             f"['{self._instance_connection_string}']: Entered connect_info method"
         )
 
-        instance_data: InstanceMetadata
+        instance_data: ConnectionInfo
 
         instance_data = await self._current
         ip_address: str = instance_data.get_preferred_ip(ip_type)
